
History
=======

1.1.1
-----

- Cleanup viewlets.
  [rnix]

- Add documentation for footer viewlet.
  [rnix]

- CSS viewlets can define ``media``.
  [rnix]

1.1
---

- All Extender fields in 'settings' schema.
  [rnix]

- Context footer added.
  [espen]

1.0.1
-----

- released after adding some more documentation.
  [jensens]

0.5
---

- drop in replacement for portal logo added.
  [jensens]

- polished setup.py et al.
  [jensens]

0.4
---

- separate context images for portal background, header background and viewlet.
  [rnix]

0.3
---

- add viewlet for using context image as header background
  [rnix]

0.2
---

- typos
  [rnix]

0.1
---

- initial
  [rnix]
